@@ -93,7 +93,7 @@ class Utils():
         return result[:-1]
 
     @classmethod
-    def build_filter_params(cls, filter_, offset=0, limit=1000):
+    def build_filter_params(cls, filter_, offset=0, limit=1000, order_by=''):
         '''
         Build query params object to pass to request.get(query_params=?)
         Parameter:
@@ -106,6 +106,8 @@ class Utils():
                 query_params[f'filter[{key}]'] = filter_[key]
         query_params['offset'] = offset
         query_params['limit'] = limit
+        if order_by:
+            query_params['orderBy'] = order_by
         return query_params
 
     @classmethod
