@@ -39,7 +39,7 @@ def assignment_report(assignment_name, subs_filter={}, port=8050):
         return
 
     cohort = Cohort.find_by_id(assignment.cohort_id)
-    if not getattr(cohort, '_id', None) or not assignment._id:
+    if not getattr(cohort, '_id', None) or not cohort._id:
         print("ERROR: Cohort not found")
         return
 
